pub enum Payload<JsonType> {
None,
Json(JsonType),
Octets(Bytes),
}Expand description
Payload of a request or response to an api endpoint.
Variants
None
Json(JsonType)
This is the regular response type used by the pubhubs API.
Octets(Bytes)
Raw bytes; used, for example, by crate::api::phc::user::GetObjectEP.
Implementations
Sourceimpl<T> Payload<T>
impl<T> Payload<T>
Sourcepub fn content_type(&self) -> Option<ContentType>
pub fn content_type(&self) -> Option<ContentType>
Returns the content type appropriate for this payload
Sourcepub fn into_body(self) -> Result<Option<Bytes>>where
T: Serialize,
pub fn into_body(self) -> Result<Option<Bytes>>where
T: Serialize,
Converts this payload into bytes.
Sourcepub async fn from_client_response<S>(
resp: ClientResponse<S>,
) -> Result<Payload<T>>
pub async fn from_client_response<S>( resp: ClientResponse<S>, ) -> Result<Payload<T>>
Extracts payload from awc::ClientResponse.