pub struct ConstellationCompRes {
pub update_constellation_claim: bool,
pub update_my_constellation: bool,
}Expand description
Result of ConstellationClaim::compare.
Fields
update_constellation_claim: boolThe constellation claim is perhaps out of date, and it’s best if the originator of it is asked to update it.
update_my_constellation: boolMy constellation is perhaps out of date (based on the constellation claim, which may, or may not be trustworthy), and may need to be updated.
Implementations