pub struct DiscoveryInfoResp {
pub name: Name,
pub self_check_code: String,
pub version: Option<String>,
pub phc_url: Url,
pub jwt_key: VerifyingKey,
pub enc_key: PublicKey,
pub master_enc_key_part: Option<PublicKey>,
pub constellation_or_id: Option<ConstellationOrId>,
}Expand description
What’s returned by the DiscoveryInfo.
Warning: when modifying DiscoveryInfoResp make sure that
-
PHC will not crash on the outdated disovery info responses returned by the transcryptor and authentication server before they are updated;
-
Old authentication server and transcryptor code will not crash on the updated discovery info response returned by PHC.
Fields
name: Nameself_check_code: StringRandom string used by a server to check that it has contact with itself.
version: Option<String>The version of this server (based on git tags).
None if not available for some reason
phc_url: UrlURL of the PubHubs Central server this server tries to connect to.
jwt_key: VerifyingKeyUsed to sign JWTs from this server.
enc_key: PublicKeyUsed to encrypt messages to this server, and to create shared secrets with this server using Diffie-Hellman
master_enc_key_part: Option<PublicKey>Master encryption key part, that is, x_PHC B or x_T B in the notation of the
whitepaper. Only set for PHC or the transcryptor.
constellation_or_id: Option<ConstellationOrId>Details of the other PubHubs servers, according to this server
None when discovery has not been completed.