pub struct ErrorInfo {
pub retryable: Option<bool>,
}Expand description
Information about an ErrorCode.
Fields
retryable: Option<bool>If true, retrying the same request might result in success.
If false, the request should not be retried without relevant changes.
If None, we do not know.