pub struct Scalar {
inner: BytesWrapper<Scalar, ChangeVisitorType<(B16Encoding,), { _ }>>,
}Expand description
Wrapper around curve25519_dalek::scalar::Scalar enforcing base16 serialization.
Fields
inner: BytesWrapper<Scalar, ChangeVisitorType<(B16Encoding,), { _ }>>Implementations
Methods from Deref<Target = Scalar>
pub const ZERO: Scalar
pub const ONE: Scalar
Sourcepub fn to_bytes(&self) -> [u8; 32]
pub fn to_bytes(&self) -> [u8; 32]
Convert this Scalar to its underlying sequence of bytes.
Example
use curve25519_dalek::scalar::Scalar;
let s: Scalar = Scalar::ZERO;
assert!(s.to_bytes() == [0u8; 32]);Sourcepub fn as_bytes(&self) -> &[u8; 32]
pub fn as_bytes(&self) -> &[u8; 32]
View the little-endian byte encoding of the integer representing this Scalar.
Example
use curve25519_dalek::scalar::Scalar;
let s: Scalar = Scalar::ZERO;
assert!(s.as_bytes() == &[0u8; 32]);Sourcepub fn invert(&self) -> Scalar
pub fn invert(&self) -> Scalar
Given a nonzero Scalar, compute its multiplicative inverse.
Warning
self MUST be nonzero. If you cannot
prove that this is the case, you SHOULD NOT USE THIS
FUNCTION.
Returns
The multiplicative inverse of the this Scalar.
Example
use curve25519_dalek::scalar::Scalar;
// x = 2238329342913194256032495932344128051776374960164957527413114840482143558222
let X: Scalar = Scalar::from_bytes_mod_order([
0x4e, 0x5a, 0xb4, 0x34, 0x5d, 0x47, 0x08, 0x84,
0x59, 0x13, 0xb4, 0x64, 0x1b, 0xc2, 0x7d, 0x52,
0x52, 0xa5, 0x85, 0x10, 0x1b, 0xcc, 0x42, 0x44,
0xd4, 0x49, 0xf4, 0xa8, 0x79, 0xd9, 0xf2, 0x04,
]);
// 1/x = 6859937278830797291664592131120606308688036382723378951768035303146619657244
let XINV: Scalar = Scalar::from_bytes_mod_order([
0x1c, 0xdc, 0x17, 0xfc, 0xe0, 0xe9, 0xa5, 0xbb,
0xd9, 0x24, 0x7e, 0x56, 0xbb, 0x01, 0x63, 0x47,
0xbb, 0xba, 0x31, 0xed, 0xd5, 0xa9, 0xbb, 0x96,
0xd5, 0x0b, 0xcd, 0x7a, 0x3f, 0x96, 0x2a, 0x0f,
]);
let inv_X: Scalar = X.invert();
assert!(XINV == inv_X);
let should_be_one: Scalar = &inv_X * &X;
assert!(should_be_one == Scalar::ONE);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Scalar
impl<'de> Deserialize<'de> for Scalar
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromStr for Scalar
We implement std::str::FromStr so that this type can be used as a command-line argument with clap.
impl FromStr for Scalar
We implement std::str::FromStr so that this type can be used as a command-line argument with clap.
impl Eq for Scalar
impl StructuralPartialEq for Scalar