pub struct Signed<T> {
inner: JWT,
phantom: PhantomData<T>,
}Expand description
A signed T by encoding T into a jwt::JWT.
Fields
inner: JWTphantom: PhantomData<T>Implementations
Sourceimpl<T> Signed<T>
impl<T> Signed<T>
Sourcepub fn open<VK: VerifyingKey>(
self,
key: &VK,
constellation: Option<&Constellation>,
) -> Result<T, OpenError>where
T: Signable,
pub fn open<VK: VerifyingKey>(
self,
key: &VK,
constellation: Option<&Constellation>,
) -> Result<T, OpenError>where
T: Signable,
Opens this Signed message using the provided key.
Sourcepub fn open_without_checking_signature(self) -> Result<T, OpenError>where
T: Signable,
pub fn open_without_checking_signature(self) -> Result<T, OpenError>where
T: Signable,
Open this signed message without checking the signature. Something that should be done
only in exceptional circumstances, for example, in the phc::hub::TicketEP endpoint.
Sourcepub fn new<SK: SigningKey>(
sk: &SK,
message: &T,
valid_for: Duration,
) -> Result<Self>where
T: Signable,
pub fn new<SK: SigningKey>(
sk: &SK,
message: &T,
valid_for: Duration,
) -> Result<Self>where
T: Signable,
Like new_opts, but with None for the constellation.
Sourcepub fn new_opts<SK: SigningKey>(
sk: &SK,
message: &T,
valid_for: Duration,
constellation: Option<&Constellation>,
) -> Result<Self>where
T: Signable,
pub fn new_opts<SK: SigningKey>(
sk: &SK,
message: &T,
valid_for: Duration,
constellation: Option<&Constellation>,
) -> Result<Self>where
T: Signable,
Signs message, and returns the resulting Signed, with more options.
pub fn as_str(&self) -> &str