Signable

Trait Signable 

pub trait Signable: DeserializeOwned + Serialize {
    const CODE: MessageCode;
    const CONSTELLATION_BOUND: bool = false;
}
A type that’s used as the contents of a Signed message.

Required Associated Constants

Provided Associated Constants

const CONSTELLATION_BOUND: bool = false

Include a CONSTELLATION_CLAIM in the Signed message of this type, binding the signed message to the current Constellation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Signable for Attr

Source

const CODE: MessageCode = crate::api::MessageCode::Attr

Source

impl Signable for PpNonceInner

Source

const CODE: MessageCode = crate::api::MessageCode::PpNonce

Source

impl Signable for InfoReq

Source

const CODE: MessageCode = crate::api::MessageCode::AdminInfoReq

Source

impl Signable for UpdateConfigReq

Source

const CODE: MessageCode = crate::api::MessageCode::AdminUpdateConfigReq

Source

impl Signable for TicketContent

Source

const CODE: MessageCode = crate::api::MessageCode::PhcHubTicket

Source

impl Signable for TicketReq

Source

const CODE: MessageCode = crate::api::MessageCode::PhcHubTicketReq

Source

impl Signable for CardPseudPackage

Source

const CODE: MessageCode = crate::api::MessageCode::CardPseudPackage

Source

impl Signable for PingReq

Source

const CODE: MessageCode = crate::api::MessageCode::HubPing

Source

impl Signable for EncryptedHubPseudonymPackage

Source

const CODE: MessageCode = crate::api::MessageCode::Ehpp

Source

impl Signable for HashedHubPseudonymPackage

Source

const CODE: MessageCode = MessageCode::Hhpp

Source

const CONSTELLATION_BOUND: bool = true

Source

impl Signable for PolymorphicPseudonymPackage

Source

const CODE: MessageCode = crate::api::MessageCode::Ppp