#[non_exhaustive]#[repr(u16)]pub enum MessageCode {
Show 14 variants
PhcHubTicketReq = 1,
PhcHubTicket = 2,
PhcTHubKeyReq = 3,
PhcTHubKeyResp = 4,
AdminUpdateConfigReq = 5,
AdminInfoReq = 6,
Attr = 7,
Ppp = 8,
Ehpp = 9,
PpNonce = 10,
Hhpp = 11,
CardPseudPackage = 12,
HubPing = 13,
Example = 65_535,
}Expand description
A number that represents the type of a message. Every message type that’s Signed gets such a code to prevent reuse of a message of one type as another.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PhcHubTicketReq = 1
PhcHubTicket = 2
PhcTHubKeyReq = 3
👎Deprecated: legacy; was used by phct::hub::KeyEP
PhcTHubKeyResp = 4
👎Deprecated: legacy; was used by phct::hub::KeyEP
AdminUpdateConfigReq = 5
AdminInfoReq = 6
Attr = 7
Ppp = 8
Ehpp = 9
PpNonce = 10
Hhpp = 11
CardPseudPackage = 12
HubPing = 13
Example = 65_535
Only used as an example in a doctest
Implementations