pub trait Signable: DeserializeOwned + Serialize {
const CODE: MessageCode;
const CONSTELLATION_BOUND: bool = false;
}Expand description
A type that’s used as the contents of a Signed message.
Required Associated Constants
const CODE: MessageCode
Provided Associated Constants
Sourceconst CONSTELLATION_BOUND: bool = false
const CONSTELLATION_BOUND: bool = false
Include a CONSTELLATION_CLAIM in the Signed message of this type, binding the
signed message to the current Constellation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.